@@ -146,37 +146,22 @@ static struct {
 	char     *mime_type;
 	gboolean  is_compressed;
 } archive_mime_types[] = {
-		{ "application/x-7z-compressed", TRUE },
-		{ "application/x-7z-compressed-tar", TRUE },
 		{ "application/x-ace", TRUE },
 		{ "application/x-alz", TRUE },
 		{ "application/x-ar", TRUE },
 		{ "application/x-arj", TRUE },
-		{ "application/x-bzip", TRUE },
-		{ "application/x-bzip-compressed-tar", TRUE },
-		{ "application/x-bzip1", TRUE },
-		{ "application/x-bzip1-compressed-tar", TRUE },
 		{ "application/vnd.ms-cab-compressed", TRUE },
 		{ "application/x-cbr", TRUE },
 		{ "application/x-cbz", TRUE },
 		{ "application/x-cd-image", FALSE },
-		{ "application/x-compress", TRUE },
-		{ "application/x-compressed-tar", TRUE },
-		{ "application/x-cpio", TRUE },
 		{ "application/x-deb", TRUE },
 		{ "application/vnd.debian.binary-package", TRUE },
 		{ "application/x-ear", TRUE },
 		{ "application/x-ms-dos-executable", FALSE },
 		{ "application/x-gtar", FALSE },
-		{ "application/x-gzip", TRUE },
 		{ "application/x-gzpostscript", TRUE },
 		{ "application/x-java-archive", TRUE },
-		{ "application/x-lha", TRUE },
 		{ "application/x-lhz", TRUE },
-		{ "application/x-lzip", TRUE },
-		{ "application/x-lzip-compressed-tar", TRUE },
-		{ "application/x-lzma", TRUE },
-		{ "application/x-lzma-compressed-tar", TRUE },
 		{ "application/x-lzop", TRUE },
 		{ "application/x-lzop-compressed-tar", TRUE },
 		{ "application/x-ms-wim", TRUE },
@@ -184,16 +169,9 @@ static struct {
 		{ "application/x-rar-compressed", TRUE },
 		{ "application/x-rpm", TRUE },
 		{ "application/x-rzip", TRUE },
-		{ "application/x-tar", FALSE },
-		{ "application/x-tarz", TRUE },
 		{ "application/x-stuffit", TRUE },
 		{ "application/x-war", TRUE },
-		{ "application/x-xz", TRUE },
-		{ "application/x-xz-compressed-tar", TRUE },
-		{ "application/x-zip", TRUE },
-		{ "application/x-zip-compressed", TRUE },
 		{ "application/x-zoo", TRUE },
-		{ "application/zip", TRUE },
 		{ "multipart/x-zip", TRUE },
 		{ NULL, FALSE }
 };
